@@ -2,11 +2,11 @@ try:
     from bae.api import logging
 except:
     import logging
-    from httpc import logger
-    def init_logging(set_level = logging.WARNING, 
-                 console = True,
-                 log_file_path = None):
-        common.init_logging(httpc.logger, set_level, console, log_file_path)
+    from httpc import #logger
+    #def init_logging(set_level = logging.WARNING, 
+    #             console = True,
+    #             log_file_path = None):
+    #    common.init_logging(httpc.#logger, set_level, console, log_file_path)
     
 from bcs import BCS
 from bucket import Bucket
